@@ -2,11 +2,9 @@ from plotly import io as pio
 from deephaven.plugin import Registration, Callback
 from deephaven.plugin.utilities import create_js_plugin, DheSafeCallbackWrapper
 from . import DeephavenFigureType
-from ._js_plugin import ExpressJsPlugin
 
 PACKAGE_NAMESPACE = "deephaven.plot.express"
 JS_NAME = "_js"
-PLUGIN_CLASS = ExpressJsPlugin
 
 
 class ExpressRegistration(Registration):
@@ -31,10 +29,6 @@ class ExpressRegistration(Registration):
 
         callback.register(DeephavenFigureType)
 
-        js_plugin = create_js_plugin(
-            PACKAGE_NAMESPACE,
-            JS_NAME,
-            PLUGIN_CLASS,
-        )
+        js_plugin = create_js_plugin(PACKAGE_NAMESPACE, JS_NAME)
 
         callback.register(js_plugin)
