@@ -7,4 +7,9 @@ from .data_generators import (
     election,
     wind,
     gapminder,
+    fish_market,
+    outages,
+    flights,
+    OUTAGE_CENTER,
+    FLIGHT_CENTER,
 )
