@@ -3,5 +3,11 @@ from .DeephavenFigure import (
     DeephavenFigureNode,
 )
 from .generate import generate_figure, update_traces
-from .custom_draw import draw_ohlc, draw_candlestick, draw_density_heatmap
+from .custom_draw import (
+    draw_ohlc,
+    draw_candlestick,
+    draw_density_heatmap,
+    draw_indicator,
+)
 from .RevisionManager import RevisionManager
+from .FigureCalendar import Calendar
