@@ -1,20 +1,22 @@
 from __future__ import annotations
 
-import sys
 from collections.abc import Generator, Callable
+from copy import copy
 from typing import Any, cast, Tuple, Dict
 
 import plotly.express as px
 from pandas import DataFrame
 
 from deephaven.table import Table, PartitionedTable
-from deephaven import pandas as dhpd
-from deephaven import merge, empty_table
+from deephaven import pandas as dhpd, empty_table
+from deephaven import merge
 
 from ._layer import atomic_layer
 from .. import DeephavenFigure
 from ..preprocess.Preprocessor import Preprocessor
 from ..shared import get_unique_names
+from ..types import AttachedTransforms, HierarchicalTransforms
+from .subplots import atomic_make_grid
 
 PARTITION_ARGS = {
     "by": None,
@@ -24,6 +26,9 @@ PARTITION_ARGS = {
     "size": ("size_sequence", "size_map"),
     "line_dash": ("line_dash_sequence", "line_dash_map"),
     "width": ("width_sequence", "width_map"),
+    "increasing_color": ("increasing_color_sequence", "increasing_color_map"),
+    "decreasing_color": ("decreasing_color_sequence", "decreasing_color_map"),
+    "gauge_color": ("gauge_color_sequence", "gauge_color_map"),
 }
 
 FACET_ARGS = {"facet_row", "facet_col"}
@@ -44,6 +49,23 @@ STYLE_DEFAULTS = {
     "pattern_shape": ["", "/", "\\", "x", "+", "."],
     "size": [4, 5, 6, 7, 8, 9],
     "width": [4, 5, 6, 7, 8, 9],
+    # these are plot by but do not currently have a default sequence
+    # setting them to None ensures they don't have to be removed in the
+    # client for theming to work
+    "increasing_color": None,
+    "decreasing_color": None,
+    "gauge_color": None,
+}
+
+# params that invoke plot bys and have no special cases like color and size
+PLOT_BY_ONLY = {
+    "pattern_shape",
+    "symbol",
+    "line_dash",
+    "width",
+    "gauge_color",
+    "increasing_color",
+    "decreasing_color",
 }
 
 
@@ -103,25 +125,76 @@ def is_single_numeric_col(val: str | list[str], numeric_cols: set[str]) -> bool:
     return (isinstance(val, str) or len(val) == 1) and val in numeric_cols
 
 
+def update_title(
+    args: dict[str, Any], count: int, title: str | None, types: set[str]
+) -> dict[str, Any]:
+    """
+    Update the title
+
+    Args:
+        args: Args used to determine the title
+        count: The number of partitions
+        title: The title to update
+        types: The types of the plot
+
+    Returns:
+        dict[str, Any]: The updated title args
+    """
+    title_args = {}
+    if "indicator" in types:
+        text_indicator = args.get("text_indicator")
+
+        if "current_partition" in args:
+            partition_title = ", ".join(args["current_partition"].values())
+            if count == 1:
+                # if there is only one partition, the title should still be on the indicator itself
+                # because of excessive padding when using the layout title
+                title_args["title"] = title
+            else:
+                title_args["layout_title"] = title
+
+            if text_indicator is None:
+                # if there is no text column, the partition names should be used
+                # text can be False, which doesn't show text, so check for None specifically
+                if title:
+                    # add the title to the layout as it could be possibly overwritten if count == 1
+                    title_args["layout_title"] = title
+                title_args["title"] = partition_title
+        elif title is not None:
+            # there must be only one trace, so put the title on the indicator itself
+            # this will be overwritten if there is a text column
+            title_args["title"] = title
+
+        # regardless of if there is a partition or not, the title should be on the layout
+        # if there is a text column
+        if text_indicator and title:
+            # there is text, so add the title to the layout as it could be possibly overwritten if count == 1
+            title_args["layout_title"] = title
+
+    elif title is not None:
+        # currently, only indicators that are partitions have custom title behavior
+        # so this is the default behavior
+        title_args["title"] = title
+    return title_args
+
+
 class PartitionManager:
     """
     Handles all partitions for the given args
 
     Attributes:
         by_vars: set[str]: The set of by_vars that can be used in a plot by
-        list_var: str: "x" or "y" depending on which var is a list
-        cols: str | list: The columns set by the list_var
-        pivot_vars: dict[str, str]: A dictionary that stores the "real" column
-          names if there is a list_var. This is needed in case the column names
+        list_param: str: "x" or "y" depending on which param is a list
+        cols: str | list: The columns set by the list_param
+        stacked_column_names: dict[str, str]: A dictionary that stores the "real" column
+          names if there is a list_param. This is needed in case the column names
           used are already in the table.
         has_color: bool: True if this figure has user set color, False otherwise
         facet_row: str: The facet row
         facet_col: str: The facet col
-        (arg, col), (map, ls, new_col)
-        always_attached: dict[tuple[str, str],
-          tuple[dict[str, str], list[str], str]: The dict mapping the arg and column
-          to the style map, dictionary, and new column name, to be used for
-          AttachedProcessor when dealing with an "always_attached" plot
+        attached_transforms: to be used for AttachedProcessor when dealing with an "always_attached" plot
+        hierarchical_transforms: HierarchicalTransforms: to be used for HierarchicalProcessor when dealing with
+            a hierarchical plot with a path
         marginal_x: Type of marginal on the x-axis, if applicable
         marginal_y: Type of marginal on the y-axis, if applicable
         marg_args: dict[str, Any]: The dictionary of args to pass to marginals
@@ -146,13 +219,14 @@ class PartitionManager:
     ):
         self.by = None
         self.by_vars = None
-        self.list_var = None
+        self.list_param = None
         self.cols = None
-        self.pivot_vars = {}
+        self.stacked_column_names = {}
         self.has_color = None
         self.facet_row = None
         self.facet_col = None
-        self.always_attached = {}
+        self.attached_transforms = AttachedTransforms()
+        self.hierarchical_transforms = HierarchicalTransforms()
 
         self.marginal_x = args.pop("marginal_x", None)
         self.marginal_y = args.pop("marginal_y", None)
@@ -161,15 +235,23 @@ class PartitionManager:
         self.marg_color = None
 
         self.args = args
-        self.groups = groups if groups else set()
+        # in some cases, such as violin plots, the default groups are a static object that is shared and should
+        # be copied to not modify the original
+        self.groups = copy(groups) if groups else set()
+        self.grid_rows = args.pop("rows", None)
+        self.grid_cols = args.pop("cols", None)
+        self.indicator = "indicator" in self.groups
         self.preprocessor = None
         self.set_long_mode_variables()
         self.convert_table_to_long_mode()
         self.key_column_table = None
+        self.send_default_figure = False
         self.partitioned_table = self.process_partitions()
         self.draw_figure = draw_figure
         self.constituents = []
 
+        self.title = args.pop("title", None)
+
     def set_long_mode_variables(self) -> None:
         """
         If dealing with a "supports_lists" plot, set variables that will be
@@ -197,19 +279,19 @@ class PartitionManager:
             self.groups.discard("supports_lists")
             return
 
-        self.list_var = var
+        self.list_param = var
         self.cols = cols
 
-        args["current_var"] = self.list_var
+        args["current_var"] = self.list_param
 
-        self.pivot_vars = get_unique_names(table, ["variable", "value"])
-        self.args["pivot_vars"] = self.pivot_vars
+        self.stacked_column_names = get_unique_names(table, ["variable", "value"])
+        self.args["stacked_column_names"] = self.stacked_column_names
 
     def convert_table_to_long_mode(
         self,
     ) -> None:
         """
-        Convert a table to long mode if thie plot supports lists
+        Convert a table to long mode if this plot supports lists
         If there is no by arg, the new column becomes it
 
         """
@@ -225,11 +307,11 @@ class PartitionManager:
 
         # if there is no plot by arg, the variable column becomes it
         if not self.args.get("by", None):
-            args["by"] = self.pivot_vars["variable"]
+            args["by"] = self.stacked_column_names["variable"]
 
         args["table"] = self.to_long_mode(table, self.cols)
 
-    def is_by(self, arg: str, map_val: str | list[str] | None = None) -> None:
+    def is_by(self, arg: str, map_val: str | list[str] | dict | None = None) -> None:
         """
         Given that the specific arg is a by arg, prepare the arg depending on
         if it is attached or not
@@ -244,10 +326,16 @@ class PartitionManager:
 
         if "always_attached" in self.groups:
             new_col = get_unique_names(self.args["table"], [arg])[arg]
-            self.always_attached[(arg, self.args[arg])] = (
-                map_val,
-                self.args[seq_arg],
-                new_col,
+            if not isinstance(map_val, dict) and map_val is not None:
+                raise TypeError(
+                    f"Expected a dictionary for {arg} map, got {type(map_val)}"
+                )
+            self.attached_transforms.add(
+                by_col=self.args[arg],
+                new_col=new_col,
+                style_map=map_val,
+                style_list=self.args[seq_arg],
+                style=arg,
             )
             # a new column will be constructed so this color is always updated
             self.args[f"attached_{arg}"] = new_col
@@ -255,12 +343,16 @@ class PartitionManager:
         else:
             map_arg = PARTITION_ARGS[arg][1]
             map_val = self.args[map_arg]
+
             if map_val == "by":
                 self.args[map_arg] = None
             if isinstance(map_val, tuple):
                 # the first element should be "by" and the map should be in the second, although a tuple with only "by"
                 # in it should also work
                 self.args[map_arg] = map_val[1] if len(map_val) == 2 else None
+            if self.args[arg] is None and self.by_vars and arg in self.by_vars:
+                # if there is no column specified for this specific arg, the by column is used
+                self.args[arg] = self.args["by"]
             self.args[f"{arg}_by"] = self.args.pop(arg)
 
     def handle_plot_by_arg(
@@ -310,9 +402,13 @@ class PartitionManager:
             ):
                 if "always_attached" in self.groups:
                     args["colors"] = args.pop("color")
-                # just keep the argument in place so it can be passed to plotly
-                # express directly
-                pass
+                    if self.args.get("path"):
+                        # is_single_numeric_col must be true so it is safe to pull the first element
+                        if not isinstance(val, str):
+                            val = val[0]
+                        # numeric column that is the source of color need to be aggregated if path is passed
+                        self.hierarchical_transforms.add(avg_col=val)
+                    # otherwise the colors are attached directly
             elif val:
                 self.is_by(arg, args[map_name])
             elif plot_by_cols and (
@@ -344,7 +440,7 @@ class PartitionManager:
                     self.args["size_sequence"] = STYLE_DEFAULTS[arg]
                 args["size_by"] = plot_by_cols
 
-        elif arg in {"pattern_shape", "symbol", "line_dash", "width"}:
+        elif arg in PLOT_BY_ONLY:
             seq_name, map_name = PARTITION_ARGS[arg][0], PARTITION_ARGS[arg][1]
             seq, map_ = args[seq_name], args[map_name]
             if map_ == "by" or isinstance(map_, dict):
@@ -386,9 +482,34 @@ class PartitionManager:
         else:
             self.by_vars = set()
 
+        filter_by = args.pop("filter_by", [])
+        required_filter_by = args.pop("required_filter_by", [])
+
+        partition_cols.update(filter_by)
+        partition_cols.update(required_filter_by)
+
+        filters = args.pop("filters", None)
+        if filters is None and (filter_by or required_filter_by):
+            # if there are input filters wait for them before creating the proper chart
+            # the python figure is created, then the filters are sent from the client
+            self.send_default_figure = True
+        elif filters is not None:
+            for required_filter in required_filter_by:
+                if (filters and required_filter not in filters) or not filters:
+                    self.send_default_figure = True
+
         if isinstance(args["table"], PartitionedTable):
             partitioned_table = args["table"]
 
+            required_filters_available = True
+            for required_filter in required_filter_by:
+                if (filters and required_filter not in filters) or not filters:
+                    required_filters_available = False
+
+            if filters and required_filters_available:
+                built_filter = [f"{k}=`{v}`" for k, v in filters.items()]
+                partitioned_table = partitioned_table.filter(built_filter)
+
         # save the by arg so it can be reused in renders,
         # especially if it was overriden
         self.by = args.get("by", None)
@@ -408,15 +529,28 @@ class PartitionManager:
                     self.facet_row = val
                 else:
                     self.facet_col = val
+            """
+            if arg == "text":
+                if self.by and val is None and self.indicator:
+                    # if by is set, text should be set to "by" by default
+                    # note that text can be False, which doesn't show text,
+                    # so check for None specifically
+                    args["text"] = self.by
+            """
 
         # it's possible that by vars are set but by_vars is None,
-        # so partitioning is still needed but it won't affect styles
+        # so partitioning is still needed, but it won't affect styles
         if not self.by_vars and self.by:
             partition_cols.update(self.by if isinstance(self.by, list) else [self.by])
 
         # preprocessor needs to be initialized after the always attached arguments are found
         self.preprocessor = Preprocessor(
-            args, self.groups, self.always_attached, self.pivot_vars
+            args,
+            self.groups,
+            self.attached_transforms,
+            self.hierarchical_transforms,
+            self.stacked_column_names,
+            self.list_param,
         )
 
         if partition_cols:
@@ -424,6 +558,7 @@ class PartitionManager:
                 partitioned_table = cast(Table, args["table"]).partition_by(
                     list(partition_cols)
                 )
+
             if not self.key_column_table:
                 self.key_column_table = partitioned_table.table.drop_columns(
                     "__CONSTITUENT__"
@@ -466,12 +601,14 @@ class PartitionManager:
         Returns:
             The ternary string that builds the new column
         """
-        ternary_string = f"{self.pivot_vars['value']} = "
+        ternary_string = f"{self.stacked_column_names['value']} = "
         for i, col in enumerate(cols):
             if i == len(cols) - 1:
                 ternary_string += f"{col}"
             else:
-                ternary_string += f"{self.pivot_vars['variable']} == `{col}` ? {col} : "
+                ternary_string += (
+                    f"{self.stacked_column_names['variable']} == `{col}` ? {col} : "
+                )
         return ternary_string
 
     def to_long_mode(self, table: Table, cols: list[str] | None) -> Table:
@@ -492,7 +629,7 @@ class PartitionManager:
         new_tables = []
         for col in cols:
             new_tables.append(
-                table.update_view(f"{self.pivot_vars['variable']} = `{col}`")
+                table.update_view(f"{self.stacked_column_names['variable']} = `{col}`")
             )
 
         merged = merge(new_tables)
@@ -543,16 +680,19 @@ class PartitionManager:
         Yields:
             The tuple of table and current partition
         """
-        column = self.pivot_vars["value"] if self.pivot_vars else None
-        if self.preprocessor:
-            tables = self.preprocessor.preprocess_partitioned_tables(
-                self.constituents, column
-            )
-            for table, current_partition in zip(
-                tables, self.current_partition_generator()
-            ):
-                # since this is preprocessed it will always be a tuple
-                yield cast(Tuple[Table, Dict[str, str]], (table, current_partition))
+        column = (
+            self.stacked_column_names["value"] if self.stacked_column_names else None
+        )
+
+        if self.preprocessor is None:
+            return
+
+        tables = self.preprocessor.preprocess_partitioned_tables(
+            self.constituents, column
+        )
+        for table, current_partition in zip(tables, self.current_partition_generator()):
+            # since this is preprocessed it will always be a tuple
+            yield cast(Tuple[Table, Dict[str, str]], (table, current_partition))
 
     def partition_generator(self) -> Generator[dict[str, Any], None, None]:
         """
@@ -569,21 +709,19 @@ class PartitionManager:
                     # if a tuple is returned here, it was preprocessed already so pivots aren't needed
                     table, arg_update = table
                     args.update(arg_update)
-                elif self.pivot_vars and self.pivot_vars["value"] and self.list_var:
+                elif (
+                    self.stacked_column_names
+                    and self.stacked_column_names["value"]
+                    and self.list_param
+                ):
                     # there is a list of variables, so replace them with the combined column
-                    args[self.list_var] = self.pivot_vars["value"]
+                    args[self.list_param] = self.stacked_column_names["value"]
 
                 args["current_partition"] = current_partition
-
                 args["table"] = table
                 yield args
-        elif (
-            "preprocess_hist" in self.groups
-            or "preprocess_freq" in self.groups
-            or "preprocess_time" in self.groups
-            or "preprocess_heatmap" in self.groups
-        ) and self.preprocessor:
-            # still need to preprocess the base table
+        elif self.preprocessor:
+            # still need to preprocess the base table if preprocessors were created
             table, arg_update = cast(
                 Tuple,
                 [*self.preprocessor.preprocess_partitioned_tables([args["table"]])][0],
@@ -605,9 +743,10 @@ class PartitionManager:
         # there are no partitions until a better solution can be done
         # also need the px template to be set
         # the title can also be set here as it will never change
-        title = self.args.get("title")
+        title = self.title
         default_fig = px.scatter(x=[0], y=[0], title=title)
         default_fig.update_traces(x=[], y=[])
+        default_fig.update_layout(margin=None)
         return DeephavenFigure(default_fig)
 
     def create_figure(self) -> DeephavenFigure:
@@ -618,6 +757,9 @@ class PartitionManager:
         Returns:
             The new figure
         """
+        if self.send_default_figure:
+            return self.default_figure()
+
         if isinstance(self.partitioned_table, PartitionedTable):
             # lock constituents in case they are deleted
             self.constituents = [*self.partitioned_table.constituent_tables]
@@ -628,6 +770,12 @@ class PartitionManager:
         trace_generator = None
         figs = []
         for i, args in enumerate(self.partition_generator()):
+            title_update = update_title(
+                args, len(self.constituents), self.title, self.groups
+            )
+
+            args = {**args, **title_update}
+
             fig = self.draw_figure(call_args=args, trace_generator=trace_generator)
             if not trace_generator:
                 trace_generator = fig.get_trace_generator()
@@ -665,7 +813,12 @@ class PartitionManager:
             figs.append(fig)
 
         try:
-            layered_fig = atomic_layer(*figs, which_layout=0)
+            if self.indicator:
+                layered_fig = atomic_make_grid(
+                    *figs, rows=self.grid_rows, cols=self.grid_cols
+                )
+            else:
+                layered_fig = atomic_layer(*figs, which_layout=0)
         except ValueError:
             return self.default_figure()
 
@@ -678,8 +831,8 @@ class PartitionManager:
             # by color (colors might be used multiple times)
             self.marg_args["table"] = self.partitioned_table
 
-            if self.pivot_vars and self.pivot_vars["value"]:
-                self.marg_args[self.list_var] = self.pivot_vars["value"]
+            if self.stacked_column_names and self.stacked_column_names["value"]:
+                self.marg_args[self.list_param] = self.stacked_column_names["value"]
 
             self.marg_args["color"] = self.marg_color
 
