@@ -1,19 +1,18 @@
 from __future__ import annotations
 
-from numbers import Number
 from typing import Callable
+import warnings
 
 from plotly import express as px
 
-from deephaven.table import Table
-
 from ._private_utils import process_args
 from ..shared import default_callback
 from ..deephaven_figure import DeephavenFigure
+from ..types import PartitionableTableLike, TableLike
 
 
 def scatter_geo(
-    table: Table | None = None,
+    table: PartitionableTableLike,
     lat: str | None = None,
     lon: str | None = None,
     locations: str | None = None,
@@ -22,13 +21,15 @@ def scatter_geo(
     featureidkey: str = "id",
     by: str | list[str] | None = None,
     by_vars: str | list[str] = "color",
+    filter_by: str | list[str] | bool | None = None,
+    required_filter_by: str | list[str] | bool | None = None,
     color: str | list[str] | None = None,
     symbol: str | list[str] | None = None,
     size: str | list[str] | None = None,
     text: str | None = None,
     hover_name: str | None = None,
     labels: dict[str, str] | None = None,
-    color_discrete_sequence: list[str] | None = None,
+    color_discrete_sequence: str | list[str] | None = None,
     color_discrete_map: str
     | tuple[str, dict[str | tuple[str], str]]
     | dict[str | tuple[str], str]
@@ -41,8 +42,8 @@ def scatter_geo(
     | dict[str | tuple[str], str]
     | None = None,
     color_continuous_scale: list[str] | None = None,
-    range_color: list[Number] | None = None,
-    color_continuous_midpoint: Number | None = None,
+    range_color: list[float] | None = None,
+    color_continuous_midpoint: float | None = None,
     opacity: float | None = None,
     projection: str | None = None,
     scope: str | None = None,
@@ -74,6 +75,15 @@ def scatter_geo(
         Can contain size, color, and symbol.
         If associated maps or sequences are specified, they are used to map by column values
         to designs. Otherwise, default values are used.
+      filter_by: A column or list of columns that contain values to filter the chart by.
+        If a boolean is passed and the table is partitioned, all partition key columns used to
+        create the partitions are used.
+        If no filters are specified, all partitions are shown on the chart.
+      required_filter_by: A column or list of columns that contain values to filter the chart by.
+        Values set in input filters or linkers for the relevant columns determine the exact values to display.
+        If a boolean is passed and the table is partitioned, all partition key columns used to
+        create the partitions are used.
+        All required input filters or linkers must be set for the chart to display any data.
       color: A column or list of columns that contain color values.
         If only one column is passed, and it contains numeric values, the value
         is used as a value on a continuous color scale. Otherwise, the value is
@@ -150,19 +160,69 @@ def scatter_geo(
     return process_args(args, {"scatter"}, px_func=px.scatter_geo)
 
 
-def scatter_mapbox(
-    table: Table | None = None,
+def scatter_mapbox(*args, **kwargs) -> DeephavenFigure:
+    """
+    c
+    """
+    warnings.warn(
+        "scatter_mapbox is deprecated and will be removed in a future release. Use scatter_map instead.",
+        DeprecationWarning,
+        stacklevel=2,
+    )
+
+    if "style_mapbox" in kwargs:
+        kwargs["map_style"] = kwargs.pop("style_mapbox")
+
+    return scatter_map(*args, **kwargs)
+
+
+def line_mapbox(*args, **kwargs) -> DeephavenFigure:
+    """
+    Deprecated function. Use line_map instead.
+    """
+    warnings.warn(
+        "line_mapbox is deprecated and will be removed in a future release. Use line_map instead.",
+        DeprecationWarning,
+        stacklevel=2,
+    )
+
+    if "style_mapbox" in kwargs:
+        kwargs["map_style"] = kwargs.pop("style_mapbox")
+
+    return line_map(*args, **kwargs)
+
+
+def density_mapbox(*args, **kwargs) -> DeephavenFigure:
+    """
+    Deprecated function. Use density_map instead.
+    """
+    warnings.warn(
+        "density_mapbox is deprecated and will be removed in a future release. Use density_map instead.",
+        DeprecationWarning,
+        stacklevel=2,
+    )
+
+    if "style_mapbox" in kwargs:
+        kwargs["map_style"] = kwargs.pop("style_mapbox")
+
+    return density_map(*args, **kwargs)
+
+
+def scatter_map(
+    table: PartitionableTableLike,
     lat: str | None = None,
     lon: str | None = None,
     by: str | list[str] | None = None,
     by_vars: str | list[str] = "color",
+    filter_by: str | list[str] | bool | None = None,
+    required_filter_by: str | list[str] | bool | None = None,
     color: str | list[str] | None = None,
     symbol: str | list[str] | None = None,
     size: str | list[str] | None = None,
     text: str | None = None,
     hover_name: str | None = None,
     labels: dict[str, str] | None = None,
-    color_discrete_sequence: list[str] | None = None,
+    color_discrete_sequence: str | list[str] | None = None,
     color_discrete_map: str
     | tuple[str, dict[str | tuple[str], str]]
     | dict[str | tuple[str], str]
@@ -175,18 +235,18 @@ def scatter_mapbox(
     | dict[str | tuple[str], str]
     | None = None,
     color_continuous_scale: list[str] | None = None,
-    range_color: list[Number] | None = None,
-    color_continuous_midpoint: Number | None = None,
+    range_color: list[float] | None = None,
+    color_continuous_midpoint: float | None = None,
     opacity: float | None = None,
-    zoom: float | None = None,
+    zoom: float | None = 0,
     center: dict[str, float] | None = None,
-    mapbox_style: str = "open-street-map",
+    map_style: str | None = None,
     title: str | None = None,
     template: str | None = None,
     unsafe_update_figure: Callable = default_callback,
 ) -> DeephavenFigure:
     """
-    Create a scatter_mapbox plot
+    Create a scatter_map plot
 
     Args:
       table: A table to pull data from.
@@ -200,6 +260,15 @@ def scatter_mapbox(
         Can contain size, color, and symbol.
         If associated maps or sequences are specified, they are used to map by column values
         to designs. Otherwise, default values are used.
+      filter_by: A column or list of columns that contain values to filter the chart by.
+        If a boolean is passed and the table is partitioned, all partition key columns used to
+        create the partitions are used.
+        If no filters are specified, all partitions are shown on the chart.
+      required_filter_by: A column or list of columns that contain values to filter the chart by.
+        Values set in input filters or linkers for the relevant columns determine the exact values to display.
+        If a boolean is passed and the table is partitioned, all partition key columns used to
+        create the partitions are used.
+        All required input filters or linkers must be set for the chart to display any data.
       color: A column or list of columns that contain color values.
         If only one column is passed, and it contains numeric values, the value
         is used as a value on a continuous color scale. Otherwise, the value is
@@ -239,13 +308,14 @@ def scatter_mapbox(
       color_continuous_midpoint: A number that is the midpoint of the color axis
       opacity: Opacity to apply to all markers. 0 is completely transparent
         and 1 is completely opaque.
-      zoom: The zoom level of the map.
+      zoom: The zoom level of the map. 0 is the whole world, and higher values zoom in closer.
       center: A dictionary of center coordinates.
         The keys should be 'lat' and 'lon' and the values should be floats
         that represent the lat and lon of the center of the map.
-      mapbox_style: The style of the map.
-        One of 'open-street-map', 'white-bg', 'carto-positron', 'carto-darkmatter',
-        and 'stamen-terrain', 'stamen-toner', 'stamen-watercolor'
+      map_style: The style of the map. Defaults to None, which uses the theme's default.
+        If a str, one of 'basic', 'carto-darkmatter', 'carto-darkmatter-nolabels', 'carto-positron',
+        'carto-positron-nolabels', 'carto-voyager', 'carto-voyager-nolabels', 'dark', 'light',
+        'open-street-map', 'outdoors', 'satellite', 'satellite-streets', 'streets', 'white-bg'.
       title: The title of the chart
       template: The template for the chart.
       unsafe_update_figure: An update function that takes a plotly figure
@@ -257,15 +327,15 @@ def scatter_mapbox(
         mappings.
 
     Returns:
-        DeephavenFigure: A DeephavenFigure that contains the scatter_mapbox figure
+        DeephavenFigure: A DeephavenFigure that contains the scatter_map figure
     """
     args = locals()
 
-    return process_args(args, {"scatter"}, px_func=px.scatter_mapbox)
+    return process_args(args, {"scatter"}, px_func=px.scatter_map)
 
 
 def line_geo(
-    table: Table | None = None,
+    table: PartitionableTableLike,
     lat: str | None = None,
     lon: str | None = None,
     locations: str | None = None,
@@ -274,6 +344,8 @@ def line_geo(
     featureidkey: str = "id",
     by: str | list[str] | None = None,
     by_vars: str | list[str] = "color",
+    filter_by: str | list[str] | bool | None = None,
+    required_filter_by: str | list[str] | bool | None = None,
     color: str | list[str] | None = None,
     symbol: str | list[str] | None = None,
     size: str | list[str] | None = None,
@@ -282,7 +354,7 @@ def line_geo(
     text: str | None = None,
     hover_name: str | None = None,
     labels: dict[str, str] | None = None,
-    color_discrete_sequence: list[str] | None = None,
+    color_discrete_sequence: str | list[str] | None = None,
     color_discrete_map: dict[str | tuple[str], str] | None = None,
     symbol_sequence: list[str] | None = None,
     symbol_map: dict[str | tuple[str], str] | None = None,
@@ -323,6 +395,15 @@ def line_geo(
         Can contain size, line_dash, width, color, and symbol.
         If associated maps or sequences are specified, they are used to map by column values
         to designs. Otherwise, default values are used.
+      filter_by: A column or list of columns that contain values to filter the chart by.
+        If a boolean is passed and the table is partitioned, all partition key columns used to
+        create the partitions are used.
+        If no filters are specified, all partitions are shown on the chart.
+      required_filter_by: A column or list of columns that contain values to filter the chart by.
+        Values set in input filters or linkers for the relevant columns determine the exact values to display.
+        If a boolean is passed and the table is partitioned, all partition key columns used to
+        create the partitions are used.
+        All required input filters or linkers must be set for the chart to display any data.
       color: A column or list of columns that contain color values.
         If only one column is passed, and it contains numeric values, the value
         is used as a value on a continuous color scale. Otherwise, the value is
@@ -410,12 +491,14 @@ def line_geo(
     return process_args(args, {"line"}, px_func=px.line_geo)
 
 
-def line_mapbox(
-    table: Table | None = None,
+def line_map(
+    table: PartitionableTableLike,
     lat: str | None = None,
     lon: str | None = None,
     by: str | list[str] | None = None,
     by_vars: str | list[str] = "color",
+    filter_by: str | list[str] | bool | None = None,
+    required_filter_by: str | list[str] | bool | None = None,
     color: str | list[str] | None = None,
     text: str | None = None,
     size: str | list[str] | None = None,
@@ -424,7 +507,7 @@ def line_mapbox(
     line_dash: str | None = None,
     hover_name: str | None = None,
     labels: dict[str, str] | None = None,
-    color_discrete_sequence: list[str] | None = None,
+    color_discrete_sequence: str | list[str] | None = None,
     color_discrete_map: dict[str | tuple[str], str] | None = None,
     line_dash_sequence: list[str] | None = None,
     line_dash_map: dict[str | tuple[str], str] | None = None,
@@ -434,15 +517,15 @@ def line_mapbox(
     size_map: dict[str | tuple[str], str] | None = None,
     width_sequence: list[int] | None = None,
     width_map: dict[str | tuple[str], str] | None = None,
-    zoom: float | None = None,
-    mapbox_style: str = "open-street-map",
+    zoom: float | None = 0,
+    map_style: str | None = None,
     center: dict[str, float] | None = None,
     title: str | None = None,
     template: str | None = None,
     unsafe_update_figure: Callable = default_callback,
 ) -> DeephavenFigure:
     """
-    Create a line_mapbox plot
+    Create a line_map plot
 
     Args:
       table: A table to pull data from.
@@ -456,6 +539,15 @@ def line_mapbox(
         Can contain size, line_dash, width, color, and symbol.
         If associated maps or sequences are specified, they are used to map by column values
         to designs. Otherwise, default values are used.
+      filter_by: A column or list of columns that contain values to filter the chart by.
+        If a boolean is passed and the table is partitioned, all partition key columns used to
+        create the partitions are used.
+        If no filters are specified, all partitions are shown on the chart.
+      required_filter_by: A column or list of columns that contain values to filter the chart by.
+        Values set in input filters or linkers for the relevant columns determine the exact values to display.
+        If a boolean is passed and the table is partitioned, all partition key columns used to
+        create the partitions are used.
+        All required input filters or linkers must be set for the chart to display any data.
       color: A column or list of columns that contain color values.
         If only one column is passed, and it contains numeric values, the value
         is used as a value on a continuous color scale. Otherwise, the value is
@@ -504,13 +596,14 @@ def line_mapbox(
         widths, widths will be reused. This is overriden if "line_dash" is specified.
       line_dash_map: If dict, the keys should be strings of the column values (or a tuple
         of combinations of column values) which map to line_dash.
-      zoom: The zoom level of the map.
+      zoom: The zoom level of the map. 0 is the whole world, and higher values zoom in closer.
       center: A dictionary of center coordinates.
         The keys should be 'lat' and 'lon' and the values should be floats
         that represent the lat and lon of the center of the map.
-      mapbox_style: The style of the map.
-        One of 'open-street-map', 'white-bg', 'carto-positron', 'carto-darkmatter',
-        and 'stamen-terrain', 'stamen-toner', 'stamen-watercolor'
+      map_style: The style of the map. Defaults to None, which uses the theme's default.
+        If a str, one of 'basic', 'carto-darkmatter', 'carto-darkmatter-nolabels', 'carto-positron',
+        'carto-positron-nolabels', 'carto-voyager', 'carto-voyager-nolabels', 'dark', 'light',
+        'open-street-map', 'outdoors', 'satellite', 'satellite-streets', 'streets', 'white-bg'.
       title: The title of the chart
       template: The template for the chart.
       unsafe_update_figure: An update function that takes a plotly figure
@@ -522,16 +615,16 @@ def line_mapbox(
         mappings.
 
     Returns:
-        DeephavenFigure: A DeephavenFigure that contains the line_mapbox figure
+        DeephavenFigure: A DeephavenFigure that contains the line_map figure
 
     """
     args = locals()
 
-    return process_args(args, {"line"}, px_func=px.line_mapbox)
+    return process_args(args, {"line"}, px_func=px.line_map)
 
 
-def density_mapbox(
-    table: Table | None = None,
+def density_map(
+    table: TableLike,
     lat: str | None = None,
     lon: str | None = None,
     z: str | None = None,
@@ -542,15 +635,15 @@ def density_mapbox(
     labels: dict[str, str] | None = None,
     radius: int = 30,
     opacity: float | None = None,
-    zoom: float | None = None,
+    zoom: float | None = 0,
     center: dict[str, float] | None = None,
-    mapbox_style: str = "open-street-map",
+    map_style: str | None = None,
     title: str | None = None,
     template: str | None = None,
     unsafe_update_figure: Callable = default_callback,
 ) -> DeephavenFigure:
     """
-    Create a density_mapbox plot
+    Create a density_map plot
 
     Args:
       table: A table to pull data from.
@@ -565,13 +658,14 @@ def density_mapbox(
       radius: The radius of each point.
       opacity: Opacity to apply to all markers. 0 is completely transparent
         and 1 is completely opaque.
-      zoom: The zoom level of the map.
+      zoom: The zoom level of the map. 0 is the whole world, and higher values zoom in closer.
       center: A dictionary of center coordinates.
         The keys should be 'lat' and 'lon' and the values should be floats
         that represent the lat and lon of the center of the map.
-      mapbox_style: The style of the map.
-        One of 'open-street-map', 'white-bg', 'carto-positron', 'carto-darkmatter',
-        and 'stamen-terrain', 'stamen-toner', 'stamen-watercolor'
+      map_style: The style of the map. Defaults to None, which uses the theme's default.
+        If a str, one of 'basic', 'carto-darkmatter', 'carto-darkmatter-nolabels', 'carto-positron',
+        'carto-positron-nolabels', 'carto-voyager', 'carto-voyager-nolabels', 'dark', 'light',
+        'open-street-map', 'outdoors', 'satellite', 'satellite-streets', 'streets', 'white-bg'.
       title: The title of the chart
       template: The template for the chart.
       unsafe_update_figure: An update function that takes a plotly figure
@@ -583,8 +677,8 @@ def density_mapbox(
         mappings.
 
     Returns:
-        DeephavenFigure: A DeephavenFigure that contains the density_mapbox figure
+        DeephavenFigure: A DeephavenFigure that contains the density_map figure
     """
     args = locals()
 
-    return process_args(args, set(), px_func=px.density_mapbox)
+    return process_args(args, set(), px_func=px.density_map)
